@@ -2,5 +2,4 @@
 
 from .client import DynamicsClient
 from .query_functions import ftr
-from .api_functions import fnc
-from .api_actions import act
+from .apply_functions import apl
