@@ -45,6 +45,9 @@ class DynamicsException(APIException):
     default_detail = "Dynamics Web API call failed."
     default_code = "dynamics_link_failed"
 
+    def __init__(self, detail=None, code=None, *arg, **kwargs):
+        super(DynamicsException, self).__init__(detail, code)
+
 
 class ParseError(DynamicsException):
     status_code = status.HTTP_400_BAD_REQUEST
@@ -75,10 +78,10 @@ class MethodNotAllowed(DynamicsException):
     default_detail = 'Method "{method}" not allowed.'
     default_code = "dynamics_method_not_allowed"
 
-    def __init__(self, method: str, detail: str = None):
+    def __init__(self, method: str, detail=None, code=None):
         if detail is None:
             self.default_detail = self.default_detail.format(method=method)
-        super().__init__(detail)
+        super().__init__(detail=detail, code=code)
 
 
 class DuplicateRecordError(DynamicsException):
